@@ -29,6 +29,7 @@ import httplib
 import urllib
 import https
 import time
+import codecs
 
 import config
 import utils
@@ -36,7 +37,7 @@ import remote
 import local
 
 
-VERSION = '0.4.4'
+VERSION = '0.4.7'
 
 
 def hook_setup(cmd):
@@ -220,9 +221,22 @@ def run_command(cmd, internal=False, retval=False, progress=False):
         sys.exit(1)
     sys.exit(int(data['type'] != 'success'))
 
+def unicode_output_patch():
+    for stream_name in ('stdout', 'stderr'):
+        stream = getattr(sys, stream_name)
+        encoding = getattr(stream, 'encoding', None)
+        if not encoding:
+            encoding = sys.getdefaultencoding()
+        codecinfo = codecs.lookup(encoding)
+        try:
+            codecinfo.encode(u'\u1234')
+        except UnicodeEncodeError:
+            patch_stream = codecinfo.streamwriter(stream, errors='replace')
+            setattr(sys, stream_name, patch_stream)
 
 def main():
     try:
+        unicode_output_patch()
         cmd = sys.argv
         cmd.pop(0)
         if cmd:
