@@ -93,7 +93,7 @@ def setup():
     if move_old_config() is True:
         return
     conf = {'url': 'https://api.dotcloud.com/'}
-    apikey = raw_input('Enter your api key (You can find it at http://www.dotcloud.com/accounts/settings): ')
+    apikey = raw_input('Enter your api key (You can find it at https://www.dotcloud.com/settings): ')
     if not re.match('\w{20}:\w{40}', apikey):
         die('Not a valid api key.')
     conf['apikey'] = apikey
